######################################################
Checks for conformance with the OpenType specification
######################################################

Base checks
***********

.. automodule:: fontbakery.checks.opentype
    :members:

CFF table checks
****************

.. automodule:: fontbakery.checks.opentype.cff
    :members:

DSIG table checks
*****************

.. automodule:: fontbakery.checks.opentype.dsig
    :members:

fvar table checks
*****************

.. automodule:: fontbakery.checks.opentype.fvar
    :members:

GDEF table checks
*****************

.. automodule:: fontbakery.checks.opentype.gdef
    :members:

glyf table checks
*****************

.. automodule:: fontbakery.checks.opentype.glyf
    :members:

GPOS table checks
*****************

.. automodule:: fontbakery.checks.opentype.gpos
    :members:

head table checks
*****************

.. automodule:: fontbakery.checks.opentype.head
    :members:

hhea table checks
*****************

.. automodule:: fontbakery.checks.opentype.hhea
    :members:

kern table checks
*****************

.. automodule:: fontbakery.checks.opentype.kern
    :members:

Layout-related checks
*********************

.. automodule:: fontbakery.checks.opentype.layout
    :members:

loca table checks
*****************

.. automodule:: fontbakery.checks.opentype.loca
    :members:

name table checks
*****************

.. automodule:: fontbakery.checks.opentype.name
    :members:

OS/2 table checks
*****************

.. automodule:: fontbakery.checks.opentype.os2
    :members:

post table checks
*****************

.. automodule:: fontbakery.checks.opentype.post
    :members:

STAT table checks
*****************

.. automodule:: fontbakery.checks.opentype.stat
    :members:
